@@ -34,7 +34,10 @@
 RS_ActionInfoDist2::RS_ActionInfoDist2(RS_EntityContainer& container,
                                        RS_GraphicView& graphicView)
         :RS_PreviewActionInterface("Info Dist2",
-                           container, graphicView) {}
+                           container, graphicView)
+        ,entity(NULL)
+        ,point(false)
+{}
 
 
 QAction* RS_ActionInfoDist2::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
@@ -77,6 +80,7 @@ void RS_ActionInfoDist2::trigger() {
 void RS_ActionInfoDist2::mouseMoveEvent(QMouseEvent* e) {
     RS_DEBUG->print("RS_ActionInfoDist2::mouseMoveEvent begin");
      RS_Vector mouse=snapPoint(e);
+     if(mouse.valid==false) return;
 
     switch (getStatus()) {
     case SetEntity:
@@ -112,7 +116,9 @@ void RS_ActionInfoDist2::mouseReleaseEvent(QMouseEvent* e) {
             break;
 
         case SetPoint: {
-                RS_CoordinateEvent ce(snapPoint(e));
+            RS_Vector vp=snapPoint(e);
+            if(vp.valid==false) return;
+            RS_CoordinateEvent ce(vp);
                 coordinateEvent(&ce);
             }
             break;
